@@ -10,7 +10,7 @@
  
 #include "kblocksscene.h"
 #include "kblocksgraphics.h"
-#include <QtDebug>
+#include "kblockssound.h"
 #include <KStandardDirs>
 #include <KLocale>
 #include <KGamePopupItem>
@@ -26,7 +26,9 @@ KBlocksScene::KBlocksScene() : gameState(Game_Starting), currentLevel(0), curren
     nextPiece = new Piece();
     QString themeFile(Settings::theme());
     grafx = new KBlocksGraphics(themeFile);
+    snd = new KBlocksSound(themeFile);
     setSceneRect(0, 0, grafx->m_View_Size_Width, grafx->m_View_Size_Height);
+    firstBlock=true;
 
     //playArea is our first item, non parented. We add it explicitally.
     playArea = new QGraphicsSvgItem();
@@ -57,6 +59,7 @@ KBlocksScene::~KBlocksScene()
   cleanAll();
   delete nextPiece;
   delete grafx;
+  delete snd;
 }
 
 void KBlocksScene::readSettings(const QSize & viewSize)
@@ -64,7 +67,7 @@ void KBlocksScene::readSettings(const QSize & viewSize)
   if (grafx->theme()->fileName()!=Settings::theme())
   {
     grafx->loadTheme(Settings::theme());
-    
+    snd->loadTheme(Settings::theme());
     grafx->adjustForSize(viewSize);
     updateDimensions();
   }
@@ -77,7 +80,7 @@ void KBlocksScene::drawBackground ( QPainter * painter, const QRectF & rect )
   }
 }
 
-void KBlocksScene::viewScaled(const QSize& newsize)
+void KBlocksScene::viewScaled(const QSize& /*newsize*/)
 {
   //Temporarily halt game timer while resizing elements
   //if (gameState==Game_Active) stepTimer.stop();
@@ -125,6 +128,8 @@ void KBlocksScene::updateDimensions()
 
 void KBlocksScene::step()
 {
+//   gets callet by the stepTimer
+
     foreach (Piece* piece, activePieces) {
       //check if we can move down
       if (canMove(piece, QPoint(0,1))) {
@@ -190,6 +195,7 @@ void KBlocksScene::startGame()
   currentRemovedLines = 0;
   currentPoints = 0;
   inLockPosition = false;
+  firstBlock = true;
   updateInterval = INITIAL_UPDATE_INTERVAL;
   stepTimer.setInterval(updateInterval);
   KGameDifficulty::standardLevel level = KGameDifficulty::level();
@@ -231,8 +237,6 @@ void KBlocksScene::checkHighscore()
 void KBlocksScene::pauseGame(bool pause, bool fromUI)
 {
   //Only work for paused, suspended and active states
-  /*if ((gameState!=Game_Paused)&&(gameState!=Game_Active) &&(gameState!=Game_Suspended))
-    return;*/
   QString resuming(i18n("Resuming Game")); 
   QString pausing(i18n("Game Paused")); 
   
@@ -241,7 +245,6 @@ void KBlocksScene::pauseGame(bool pause, bool fromUI)
     if (pause) {
       previousGameState = gameState;
       gameState = Game_Suspended;
-      //showMessage( pausing, 2000 );
       stepTimer.stop();
     } else {
       gameState = previousGameState;
@@ -250,24 +253,23 @@ void KBlocksScene::pauseGame(bool pause, bool fromUI)
       }
       if (gameState==Game_Paused) stepTimer.stop();
     }
-    goto setStatusAndExit;
-  }
-  
-  if ((gameState==Game_Paused)&&!pause)  {
-    stepTimer.start();
-    showMessage( resuming, 2000 );
-    gameState=Game_Active;
-  } else if ((gameState==Game_Active)&&pause){
-    showMessage( pausing, 2000 );
-    stepTimer.stop();
-    gameState=Game_Paused;
   } else {
-    //inconsistency, restore state and log
-    kDebug()<<"Inconsistent Game State at pauseGame:"<<gameState<<pause;
+     //user initiated
+    if ((gameState==Game_Paused)&&!pause)  {
+      stepTimer.start();
+      showMessage( resuming, 2000 );
+      gameState=Game_Active;
+    } else if ((gameState==Game_Active)&&pause){
+      showMessage( pausing, 2000 );
+      stepTimer.stop();
+      gameState=Game_Paused;
+    } else {
+      //inconsistency, restore state and log
+      kDebug()<<"Inconsistent Game State at pauseGame:"<<gameState<<pause;
+    }
   }
-setStatusAndExit:
   //Set KGameDifficulty state, for prompting user on restart
-  if (gameState==Game_Active) KGameDifficulty::setRunning(true);
+  if (previousGameState==Game_Active) KGameDifficulty::setRunning(true);
   else KGameDifficulty::setRunning(false);
 }
 
@@ -292,11 +294,30 @@ void KBlocksScene::attemptMove(const QPoint& delta)
   foreach (Piece* piece, activePieces) {
       //check if we can move
     if (canMove(piece, delta)) {
+      snd->playSound("Sound_Block_Move");
       movePiece(piece, delta);
     } 
   }
 }
 
+void KBlocksScene::attemptPushDown(const QPoint& delta)
+{
+  if (gameState!=Game_Active) {
+    return;
+  }
+  //check how deep we can move
+  bool moveable = true;
+  while(moveable) {
+    moveable=false;
+    foreach (Piece* piece, activePieces){
+      if (canMove(piece, delta)) {
+	movePiece(piece,delta);
+	moveable=true;
+      }
+    }
+  }
+}
+
 void KBlocksScene::attemptRotation(KBlocksRotationDirection direction)
 {
   if (gameState!=Game_Active) {
@@ -305,6 +326,7 @@ void KBlocksScene::attemptRotation(KBlocksRotationDirection direction)
   foreach (Piece* piece, activePieces) {
       //check if we can rotate
     if (canRotate(piece, direction)) {
+      snd->playSound("Sound_Block_Move");
       rotatePiece(piece, direction);
     } 
   }
@@ -313,8 +335,16 @@ void KBlocksScene::attemptRotation(KBlocksRotationDirection direction)
 void KBlocksScene::prepareNewPiece()
 {
   //Chose one of the available piece types
+  //but for the first peace only a nice one
   int availablepiecetypes = pieceTypes.size();
-  int chosenset = rand()%availablepiecetypes; 
+  int chosenset;
+  if (firstBlock){
+    chosenset = rand()%4; 
+    firstBlock=false;
+  } else {
+    chosenset = rand()%availablepiecetypes; 
+  }
+    
   //qDebug() << chosenset;
   PieceSet chosenpieceset = pieceTypes.at(chosenset);
   //From the chosen piece set we now pick an initial orientation
@@ -323,6 +353,7 @@ void KBlocksScene::prepareNewPiece()
   PieceRotation chosenpiecerotation = chosenpieceset.at(chosenorientation);
 
   //Use the piece blueprint to construct our blocks
+  //First build nextPiece
   for (int i = 0; i < chosenpiecerotation.size(); ++i) {
     Block *block = new Block(playArea);
     block->setSharedRenderer(grafx->renderer());
@@ -334,13 +365,14 @@ void KBlocksScene::prepareNewPiece()
     block->setData(Block_Coord, point);
     //Position the block initially in the preview area
     block->setPos(nextPieceCoordToPoint(point));
-      //and append them to temporary collection
+    //and append them to temporary collection
     nextPiece->addItem(block);
   }
   //Store blueprint data needed to recreate/rotate the piece
   nextPiece->setData(Piece_Set, chosenset);
   nextPiece->setData(Piece_Rotation, chosenorientation);
   
+
   //Adjust the position of the blocks so that the piece is nicely centered in the preview area
   centerPiecePreview(nextPiece);
   
@@ -534,6 +566,7 @@ void KBlocksScene::rotatePiece(Piece * piece, KBlocksRotationDirection direction
 
 void KBlocksScene::freezePiece(Piece * piece)
 {
+  snd->playSound("Sound_Block_Fall");
   foreach (Block *block, piece->children()) {
     piece->removeItem(block);
     //frozenBlocksMap.insert(coordToIndex(block->data(Block_Coord).toPoint()), block);
@@ -655,6 +688,8 @@ void KBlocksScene::addToScore(KBlocksScoreEvent type, int count)
         case 4: 
           comboLinesValue = 1200;
           break;
+        default:
+          comboLinesValue = 0;
       }
       //Classical scoring and gameplay uses level 0 as the first one
       currentPoints = currentPoints + (comboLinesValue*(currentLevel+1));
@@ -762,42 +797,6 @@ void KBlocksScene::initPieceTypes()
   pieceTypes << aset;
   aset.clear();
 
-  //Four blocks, resembling an airplane (T)
-  apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(1,0) << QPoint(-1,0);
-  aset << apiece;
-  apiece.clear();
-  apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(-1,0) << QPoint(0,1);
-  aset << apiece;
-  apiece.clear();
-  apiece << QPoint(0,0) << QPoint(1,0) << QPoint(-1,0) << QPoint(0,1); 
-  aset << apiece;
-  apiece.clear();
-  apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(1,0) << QPoint(0,1);
-  aset << apiece;
-  apiece.clear();
-  pieceTypes << aset;
-  aset.clear();
-
-  //Four blocks, stair-like (S)
-  apiece << QPoint(0,0) << QPoint(0,1) << QPoint(1,0) << QPoint(1,-1);
-  aset << apiece;
-  apiece.clear();
-  apiece << QPoint(0,0) << QPoint(-1,0) << QPoint(0,1) << QPoint(1,1);
-  aset << apiece;
-  apiece.clear();
-  pieceTypes << aset;
-  aset.clear();
-
-  //Four blocks, also stair-like (Z)
-  apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(1,0) << QPoint(1,1);
-  aset << apiece;
-  apiece.clear();
-  apiece << QPoint(0,0) << QPoint(-1,0) << QPoint(0,-1) << QPoint(1,-1);
-  aset << apiece;
-  apiece.clear();
-  pieceTypes << aset;
-  aset.clear();
-
   //Four blocks, L shape (L)
   apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(0,-2) << QPoint(1,0);
   aset << apiece;
@@ -836,6 +835,42 @@ void KBlocksScene::initPieceTypes()
   apiece.clear();
   pieceTypes << aset;
   aset.clear();
+
+  //Four blocks, resembling an airplane (T)
+  apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(1,0) << QPoint(-1,0);
+  aset << apiece;
+  apiece.clear();
+  apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(-1,0) << QPoint(0,1);
+  aset << apiece;
+  apiece.clear();
+  apiece << QPoint(0,0) << QPoint(1,0) << QPoint(-1,0) << QPoint(0,1); 
+  aset << apiece;
+  apiece.clear();
+  apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(1,0) << QPoint(0,1);
+  aset << apiece;
+  apiece.clear();
+  pieceTypes << aset;
+  aset.clear();
+
+  //Four blocks, stair-like (S)
+  apiece << QPoint(0,0) << QPoint(0,1) << QPoint(1,0) << QPoint(1,-1);
+  aset << apiece;
+  apiece.clear();
+  apiece << QPoint(0,0) << QPoint(-1,0) << QPoint(0,1) << QPoint(1,1);
+  aset << apiece;
+  apiece.clear();
+  pieceTypes << aset;
+  aset.clear();
+
+  //Four blocks, also stair-like (Z)
+  apiece << QPoint(0,0) << QPoint(0,-1) << QPoint(1,0) << QPoint(1,1);
+  aset << apiece;
+  apiece.clear();
+  apiece << QPoint(0,0) << QPoint(-1,0) << QPoint(0,-1) << QPoint(1,-1);
+  aset << apiece;
+  apiece.clear();
+  pieceTypes << aset;
+  aset.clear();
 }
 
 void KBlocksScene::showMessage( const QString& message, int ms )
@@ -843,3 +878,10 @@ void KBlocksScene::showMessage( const QString& message, int ms )
   messageItem->setMessageTimeout( ms );
   messageItem->showMessage( message, KGamePopupItem::TopLeft );
 }
+
+void KBlocksScene::setSoundsEnabled( bool enabled )
+{
+  snd->setSoundsEnabled(enabled);
+}
+
+#include "kblocksscene.moc"
