@@ -21,6 +21,7 @@
 #include "gift.h"
 #include "brick.h"
 #include "ball.h"
+#include "settings.h"
 
 #include <cmath>
 #include <math.h>
@@ -43,6 +44,8 @@ GameEngine::GameEngine(MainWindow *mainWindow)
     
     m_elapsedTimeTimer.setInterval(1000);
     connect(&m_elapsedTimeTimer, SIGNAL(timeout()), SLOT(increaseElapsedTime()));
+
+    m_cheatsEnabled = !qgetenv("KDE_DEBUG").isEmpty();
 }
 
 GameEngine::~GameEngine()
@@ -74,7 +77,7 @@ void GameEngine::start(const QString& l)
     m_gameTimer.start();
 }
 
-bool GameEngine::gameIsPaused()
+bool GameEngine::gameIsPaused() const
 {
     return !m_elapsedTimeTimer.isActive();
 }
@@ -175,7 +178,19 @@ void GameEngine::fire()
     randomCounter = 0;
 }
 
-// TODO: external level loarder???
+void GameEngine::cheatSkipLevel() 
+{
+    if (m_cheatsEnabled)
+        loadNextLevel();
+}
+
+void GameEngine::cheatAddLife() 
+{
+    if (m_cheatsEnabled)
+        m_lives.append(new Life);
+}
+
+// TODO: external level loader???
 void GameEngine::loadLevel()
 {
     
@@ -553,6 +568,7 @@ void GameEngine::showInfoMessage(const QString &text)
 
 void GameEngine::showFireBallMessage()
 {
+    if (Settings::fireOnClick()) return; // don't show message
     QAction *fireAction = m_mainWindow->actionCollection()->action("fire");
     QString shortcut = fireAction->shortcut().toString(QKeySequence::NativeText);
     showInfoMessage(i18n("Press %1 to fire the ball", shortcut));
@@ -625,6 +641,7 @@ inline void GameEngine::deleteMovingObjects()
     QMutableListIterator<Gift *> i(m_gifts);
     while (i.hasNext()) {
         Gift *gift = i.next(); 
+        // FIXME ??????????????
         if (gift->isVisible())
             delete gift;
             i.remove();
