@@ -794,7 +794,7 @@ void KWin4App::configureNetwork()
   // just for testing - should be non-modal
   KGameDialog dlg(mDoc, 0, i18n("Network Configuration"), this, KGameDialog::NetworkConfig, 20000, true);
   dlg.networkConfig()->setDefaultNetworkInfo(host, port);
-  dlg.networkConfig()->setDiscoveryInfo("_kwin4._tcp",Prefs::gamename());
+  dlg.networkConfig()->setDiscoveryInfo("_kfourinline._tcp",Prefs::gamename());
 
   KVBox *box=dlg.configPage(KGameDialog::NetworkConfig);
   QLayout *l=box->layout();
@@ -804,8 +804,8 @@ void KWin4App::configureNetwork()
   connect(mColorGroup, SIGNAL(clicked(int)), this, SLOT(remoteChanged(int)));
   connect(dlg.networkConfig(), SIGNAL(signalServerTypeChanged(int)), this, SLOT(serverTypeChanged(int)));
 
-  QRadioButton *b1 = new QRadioButton(i18n("Black should be played by remote"), mColorGroup);
-  QRadioButton *b2 = new QRadioButton(i18n("Red should be played by remote"), mColorGroup);
+  QRadioButton *b1 = new QRadioButton(i18n("Black should be played by remote player"), mColorGroup);
+  QRadioButton *b2 = new QRadioButton(i18n("Red should be played by remote player"), mColorGroup);
   grouplay->addWidget(b1);
   grouplay->addWidget(b2);
   l->addWidget(mColorGroup);
