@@ -11,13 +11,14 @@
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
 */
+
 #include "clock.h"
+
 #include "deck.h"
 #include "patsolve/clock.h"
 
-#include <cassert>
+#include <KLocale>
 
-#include <klocale.h>
 
 Clock::Clock( )
     : DealerScene( )
@@ -104,7 +105,7 @@ static class LocalDealerInfo11 : public DealerInfo
 {
 public:
     LocalDealerInfo11() : DealerInfo(I18N_NOOP("Grandfather's Clock"), 11) {}
-    virtual DealerScene *createGame() { return new Clock(); }
+    virtual DealerScene *createGame() const { return new Clock(); }
 } gfi11;
 
 #include "clock.moc"
