@@ -11,13 +11,16 @@
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
 */
+
 #include "golf.h"
-#include "speeds.h"
+
 #include "deck.h"
+#include "speeds.h"
 #include "patsolve/golf.h"
 
-#include <klocale.h>
-#include <kdebug.h>
+#include <KDebug>
+#include <KLocale>
+
 
 HorRightPile::HorRightPile( int _index, DealerScene* parent)
     : Pile(_index, parent)
@@ -38,7 +41,7 @@ Golf::Golf( )
 
     Deck::create_deck( this);
     Deck::deck()->setPilePos(1, -1);
-    connect(Deck::deck(), SIGNAL(clicked(Card*)), SLOT(deckClicked(Card*)));
+    connect(Deck::deck(), SIGNAL(clicked(Card*)), SLOT(newCards()));
 
     waste=new HorRightPile(8,this);
     waste->setPilePos(12, -1);
@@ -57,7 +60,7 @@ Golf::Golf( )
         stack[r]->setObjectName( QString( "stack%1" ).arg( r ) );
     }
 
-    setActions(DealerScene::Hint | DealerScene::Demo);
+    setActions(DealerScene::Hint | DealerScene::Demo | DealerScene::Draw);
     setSolver( new GolfSolver( this ) );
 }
 
@@ -91,21 +94,7 @@ void Golf::restart()
 {
     Deck::deck()->collectAndShuffle();
     deal();
-}
-
-void Golf::deckClicked(Card *)
-{
-    if (Deck::deck()->isEmpty()) {
-         return;
-
-    }
-    Card *c = Deck::deck()->nextCard();
-    waste->add(c, true );
-    c->stopAnimation();
-    qreal x = c->x();
-    qreal y = c->y();
-    c->setPos( Deck::deck()->pos() );
-    c->flipTo(x, y, DURATION_FLIP );
+    emit newCardsPossible( true );
 }
 
 //-------------------------------------------------------------------------//
@@ -119,14 +108,39 @@ void Golf::deal()
             stack[r]->add(Deck::deck()->nextCard(),false);
         }
     }
-    waste->add(Deck::deck()->nextCard(),false);
 
+    Card *c = Deck::deck()->nextCard();
+    waste->add(c, true);
+    qreal x = c->x();
+    qreal y = c->y();
+    c->setPos( Deck::deck()->pos() );
+    c->flipTo(x, y, DURATION_FLIP );
 }
 
-Card *Golf::demoNewCards()
+Card *Golf::newCards()
 {
-    deckClicked(0);
-    return waste->top();
+    if (Deck::deck()->isEmpty())
+         return 0;
+
+    if ( waste->top() && waste->top()->animated() )
+        return waste->top();
+
+    unmarkAll();
+
+    Card *c = Deck::deck()->nextCard();
+    waste->add(c, true );
+    c->stopAnimation();
+    qreal x = c->x();
+    qreal y = c->y();
+    c->setPos( Deck::deck()->pos() );
+    c->flipTo(x, y, DURATION_FLIP );
+
+    takeState();
+    considerGameStarted();
+    if ( Deck::deck()->isEmpty() )
+        emit newCardsPossible( false );
+
+    return c;
 }
 
 bool Golf::cardClicked(Card *c)
@@ -149,11 +163,16 @@ bool Golf::cardClicked(Card *c)
     return false;
 }
 
+void Golf::setGameState( const QString & )
+{
+    emit newCardsPossible( !Deck::deck()->isEmpty() );
+}
+
 static class LocalDealerInfo13 : public DealerInfo
 {
 public:
     LocalDealerInfo13() : DealerInfo(I18N_NOOP("Golf"), 12) {}
-    virtual DealerScene *createGame() { return new Golf(); }
+    virtual DealerScene *createGame() const { return new Golf(); }
 } ldi13;
 
 //-------------------------------------------------------------------------//
