@@ -16,28 +16,31 @@
 
  */
 
-#include <kapplication.h>
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kurl.h>
-
-#include <QtCore/QTime>
-#include <QtCore/QTimer>
-#include <QtCore/QFile>
-
-#include <QDomDocument>
-
-#include <stdio.h>
-#include <limits.h>
-
+#include "cardmaps.h"
+#include "dealer.h"
 #include "version.h"
 #include "pwidget.h"
-#include "dealer.h"
 #include "patsolve/patsolve.h"
-#include "cardmaps.h"
+
+#include <KAboutData>
+#include <KApplication>
+#include <KCmdLineArgs>
+#include <KDebug>
+#include <KGlobal>
+#include <KLocale>
+#include <KMenuBar>
+#include <KStandardDirs>
+#include <KUrl>
+
+#include <QtCore/QFile>
+#include <QtCore/QTime>
+#include <QtCore/QTimer>
+#include <QtGui/QResizeEvent>
+#include <QtXml/QDomDocument>
+
+#include <cstdio>
+#include <climits>
+
 
 static const char description[] = I18N_NOOP("KDE Patience Game");
 
@@ -47,7 +50,7 @@ static DealerScene *getDealer( int wanted_game )
     for (QList<DealerInfo*>::ConstIterator it = DealerInfoList::self()->games().begin();
          it != DealerInfoList::self()->games().end(); ++it)
     {
-        if ( (*it)->gameindex == wanted_game ) {
+        if ( (*it)->hasId(wanted_game) ) {
             di = *it;
             DealerScene *f = di->createGame();
             if ( !f || !f->solver() ) {
@@ -62,6 +65,54 @@ static DealerScene *getDealer( int wanted_game )
     return 0;
 }
 
+// A function to remove all nonalphanumeric characters from a string
+// and convert all letters to lowercase.
+QString lowerAlphaNum( const QString & string )
+{
+    QString result;
+    for ( int i = 0; i < string.size(); ++i )
+    {
+        QChar c = string.at( i );
+        if ( c.isLetterOrNumber() )
+            result += c.toLower();
+    }
+    return result;
+}
+
+// A function that forces all pending resize events to happen immediately.
+// Used to prevent expensive resize events after the scene has been created.
+void sendAllPendingResizeEvents( QWidget * widget )
+{
+    bool foundOne;
+    do
+    {
+        foundOne = false;
+        QList<QWidget *> allChildWidgets = widget->findChildren<QWidget *>();
+        allChildWidgets.prepend( widget );
+        foreach( QWidget* w, allChildWidgets )
+        {
+            if ( w->testAttribute(Qt::WA_PendingResizeEvent) )
+            {
+                QResizeEvent e(w->size(), QSize());
+                QApplication::sendEvent(w, &e);
+                w->setAttribute(Qt::WA_PendingResizeEvent, false);
+                // hack: make QTabWidget think it's visible; no layout otherwise
+                w->setAttribute(Qt::WA_WState_Visible, true);
+                foundOne = true;
+            }
+        }
+        // Process LayoutRequest events, in particular
+        qApp->sendPostedEvents();
+
+        if ( !foundOne )
+        {
+            // Reset visible flag, to avoid crashes in qt
+            foreach( QWidget* w, allChildWidgets )
+                w->setAttribute(Qt::WA_WState_Visible, false);
+        }
+    } while ( foundOne );
+}
+
 int main( int argc, char **argv )
 {
     KAboutData aboutData( "kpat", 0, ki18n("KPatience"),
@@ -85,6 +136,21 @@ int main( int argc, char **argv )
     aboutData.addAuthor(ki18n("Inge Wallin"), ki18n("Bug fixes"), "inge@lysator.liu.se");
     aboutData.addAuthor(ki18n("Simon Hürlimann"), ki18n("Menu and Toolbar work"), "simon.huerlimann@huerlisi.ch");
 
+    // Create a KLocale earlier than normal so that we can use i18n to translate
+    // the names of the game types in the help text.
+    KLocale *tmpLocale = new KLocale("kpat");
+    QMap<QString, int> indexMap;
+    QStringList gameList;
+    foreach ( const DealerInfo *di, DealerInfoList::self()->games() )
+    {
+        const QString translatedKey = lowerAlphaNum( ki18n( di->name ).toString(tmpLocale) );
+        gameList << translatedKey;
+        indexMap.insert( translatedKey, di->ids.first() );
+        indexMap.insert( lowerAlphaNum( QString( di->name ) ), di->ids.first() );
+    }
+    gameList.sort();
+    delete tmpLocale;
+
     KCmdLineArgs::init( argc, argv, &aboutData );
 
     KCmdLineOptions options;
@@ -92,6 +158,7 @@ int main( int argc, char **argv )
     options.add("solve <num>", ki18n("Dealer to solve (debug)" ));
     options.add("start <num>", ki18n("Game range start (default 0:INT_MAX)" ));
     options.add("end <num>", ki18n("Game range end (default start:start if start given)" ));
+    options.add("gametype <game>", ki18n("Skip the selection screen and load a particular game type. Valid values are: %1").subs(gameList.join(i18nc("List separator", ", "))));
     options.add("+file", ki18n("File to load"));
     KCmdLineArgs::addCmdLineOptions (options);
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
@@ -170,11 +237,32 @@ int main( int argc, char **argv )
         return 0;
     }
 
+    QString gametype = args->getOption("gametype").toLower();
+    QFile savedState( KStandardDirs::locateLocal("appdata", saved_state_file) );
+
     pWidget *w = new pWidget;
+    sendAllPendingResizeEvents(w->menuBar());
     if (args->count())
-        w->openGame(args->url(0));
+    {
+        if (!w->openGame(args->url(0)))
+            w->slotShowGameSelectionScreen();
+    }
+    else if (indexMap.contains(gametype))
+    {
+        w->slotGameSelected(indexMap.value(gametype));
+    }
+    else if (savedState.exists())
+    {
+        if (!w->openGame(savedState.fileName(), false))
+            w->slotShowGameSelectionScreen();
+        savedState.remove();
+    }
     else
-        QTimer::singleShot(100, w, SLOT(slotNewGameType()));
+    {
+        w->slotShowGameSelectionScreen();
+    }
+    w->show();
+
     args->clear();
     return application.exec();
 }
