@@ -1,30 +1,24 @@
  /* Common routines & arrays. */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
-#include <math.h>
-#include <kdebug.h>
-#include <sys/types.h>
-#include <stdarg.h>
-#include <algorithm>
 #include "gypsy.h"
+
+#include "../deck.h"
 #include "../gypsy.h"
 #include "../pile.h"
-#include "../deck.h"
 
-/* These two routines make and unmake moves. */
+#include <KDebug>
+
 
 #define PRINT 0
-#define PRINT2 0
 
 #define suitable(a, b) (COLOR( a ) != COLOR( b ) )
 
+/* These two routines make and unmake moves. */
+
 void GypsySolver::make_move(MOVE *m)
 {
 #if PRINT
-    kDebug() << "\n\nmake_move\n";
+    kDebug(11111) << "\n\nmake_move\n";
     if ( m->totype == O_Type )
         fprintf( stderr, "move %d from %d out (at %d) Prio: %d\n\n", m->card_index, m->from, m->turn_index, m->pri );
     else
@@ -112,7 +106,7 @@ void GypsySolver::make_move(MOVE *m)
 void GypsySolver::undo_move(MOVE *m)
 {
 #if PRINT
-    kDebug() << "\n\nundo_move\n";
+    kDebug(11111) << "\n\nundo_move\n";
     if ( m->totype == O_Type )
         fprintf( stderr, "move %d from %d out (at %d)\n\n", m->card_index, m->from, m->turn_index );
     else
@@ -378,7 +372,7 @@ int GypsySolver::get_possible_moves(int *a, int *numout)
                     }
                     if ( o > -1 )
                         continue;
-                    mp->pri = ( int )std::min( 127., params[1] + double( l ) * params[5] / 10 );
+                    mp->pri = ( int )qMin( 127., params[1] + double( l ) * params[5] / 10 );
                 }
                 n++;
                 mp++;
@@ -445,9 +439,9 @@ GypsySolver::GypsySolver(const Gypsy *dealer)
     for ( int i = 1; i <= 6; i++ )
     {
         sprintf( buffer, "DECK%d", i );
-        char *env = getenv( buffer );
-        if ( env )
-            params[i-1] = atoi( env );
+        const QByteArray env = qgetenv( buffer );
+        if ( !env.isEmpty() )
+            params[i-1] = env.toInt();
     }
 }
 
