@@ -1,27 +1,22 @@
 /* Common routines & arrays. */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
-#include <math.h>
-#include <kdebug.h>
-#include <sys/types.h>
-#include <stdarg.h>
 #include "spider.h"
-#include "../spider.h"
-#include "../pile.h"
-#include "../deck.h"
 
-/* These two routines make and unmake moves. */
+#include "../deck.h"
+#include "../pile.h"
+#include "../spider.h"
+
+#include <KDebug>
+
 
 #define PRINT 0
-#define PRINT2 0
+
+/* These two routines make and unmake moves. */
 
 void SpiderSolver::make_move(MOVE *m)
 {
 #if PRINT
-    kDebug() << "\n\nmake_move\n";
+    kDebug(11111) << "\n\nmake_move\n";
     if ( m->totype == O_Type )
         fprintf( stderr, "move %d from %d out (at %d) Prio: %d\n\n", m->card_index, m->from, m->turn_index, m->pri );
     else
@@ -110,7 +105,7 @@ void SpiderSolver::make_move(MOVE *m)
 void SpiderSolver::undo_move(MOVE *m)
 {
 #if PRINT
-    kDebug() << "\n\nundo_move\n";
+    kDebug(11111) << "\n\nundo_move\n";
     if ( m->totype == O_Type )
         fprintf( stderr, "move %d from %d out (at %d)\n\n", m->card_index, m->from, m->turn_index );
     else
@@ -277,6 +272,7 @@ int SpiderSolver::get_possible_moves(int *a, int *numout)
     }
 
     bool foundgood = false;
+    int toomuch = 0;
 
     for(int i=0; i<10; i++)
     {
@@ -307,9 +303,11 @@ int SpiderSolver::get_possible_moves(int *a, int *numout)
                      RANK(card) == RANK(*Wp[j]) - 1 )
                 {
                     allowed = true;
-                    if ( ( SUIT( card ) != SUIT( *Wp[j] ) ) && ( foundgood && Wlen[i] > l + 1 && l > 0 )) {
+#if 1
+                    // too bad: see bug 175945
+                    if ( ( SUIT( card ) != SUIT( *Wp[j] ) ) && ( foundgood && Wlen[i] > l + 1 && l > 0 ))
                         allowed = false; // make the tree simpler
-                    }
+#endif
                 }
                 if ( Wlen[j] == 0 && !wasempty )
                 {
@@ -331,10 +329,20 @@ int SpiderSolver::get_possible_moves(int *a, int *numout)
                         printcard( card, stderr );
                         fprintf( stderr, "%d %d %d %d %d\n", i, j, conti[i], conti[j],l );
 #endif
-                        if ( conti[j]+l+1 != 13 || conti[i]>conti[j]+l || SUIT( card ) != SUIT( *Wp[j] ) ) {
+                        if ( SUIT( card ) != SUIT( *Wp[j] ) )
+                        {
                             //fprintf( stderr, "continue %d %d %d %d\n",conti[j]+l, conti[i],conti[j]+l, SUIT( card ) != SUIT( *Wp[j] ) );
                             continue;
                         }
+
+#if 1
+                        // too bad: see bug 175945
+                        if ( conti[j]+l+1 != 13 || conti[i]>conti[j]+l )
+                        {
+                            //fprintf( stderr, "continue %d %d %d %d\n",conti[j]+l, conti[i],conti[j]+l, SUIT( card ) != SUIT( *Wp[j] ) );
+                            //continue;
+                        }
+#endif
                     }
                 }
 
@@ -353,15 +361,28 @@ int SpiderSolver::get_possible_moves(int *a, int *numout)
                         cont += l;
                     mp->pri = 8 * cont + qMax( 0, 10 - Wlen[i] );
                     if ( Wlen[j] )
+                    {
                         if ( SUIT( card ) != SUIT( *Wp[j] ) )
                             mp->pri /= 2;
-                        else
-                            foundgood = true;
-                    else
+                        else {
+                            if ( conti[j]+l+1 != 13 || conti[i]>conti[j]+l )
+                            {
+                                card_t card_below = W[i][Wlen[i]-l-2];
+                                if ( SUIT( card_below ) != SUIT( card ) )
+                                {
+                                    foundgood = true;
+                                } else {
+                                    toomuch++;
+                                    mp->pri = -40;
+                                }
+                            } else
+                                foundgood = true;
+                        }
+                    } else
                         mp->pri = 2; // TODO: it should depend on the actual stack's order
                     if ( mp->turn_index > 0)
                         mp->pri = qMin( 127, mp->pri + 7 );
-                    else  if ( Wlen[i] == l+1 )
+                    else if ( Wlen[i] == l+1 )
                         mp->pri = qMin( 127, mp->pri + 4 );
                     else
                         mp->pri = qMin( 127, mp->pri + 2 );
@@ -409,6 +430,38 @@ int SpiderSolver::get_possible_moves(int *a, int *numout)
         break; // one is enough
     }
 
+    //kDebug(11111) << "n" << n << toomuch << foundgood;
+    if ( n > toomuch && foundgood )
+    {
+        mp = Possible;
+        int i = 0;
+        while ( i < n )
+        {
+            //kDebug(11111) << "i" << i << Possible[i].pri;
+            if ( Possible[i].pri < 0 )
+            {
+                // kill it
+                Possible[i] = Possible[n-1];
+                n--;
+            } else
+                i++;
+        }
+
+        i = 0;
+        while ( i < n )
+        {
+            //kDebug(11111) << "i2" << i << Possible[i].pri;
+            if ( Possible[i].pri < 0 )
+            {
+                // kill it
+                Possible[i] = Possible[n-1];
+                n--;
+            } else
+                i++;
+        }
+
+    }
+
     return n;
 }
 
