@@ -64,6 +64,7 @@ AnimSprite::AnimSprite(const QString &svgid,
     m_timer(this),
     m_skin(backGnd->onu()->skin())
 {
+  kDebug() << svgid << nbFrames;
   setNone();
 
   sequenceConstruction();
@@ -95,7 +96,7 @@ void AnimSprite::repaint()
 
 void AnimSprite::setLook(TDir newLook)
 {
-  kDebug();
+//   kDebug();
   if (newLook != look)
   {
 //        kDebug()<<"setLook : " << newLook << ")" << endl;
@@ -114,21 +115,39 @@ void AnimSprite::sequenceConstruction()
 {
   QList<QPixmap> list;
 
-  QSize size((int)(m_width*frames), (int)(m_height*nbVersions));
-  QImage image(size, QImage::Format_ARGB32_Premultiplied);
-  image.fill(0);
-  QPainter p(&image);
-  m_renderer->render(&p, m_svgid);
-  QPixmap allpm = QPixmap::fromImage(image);
+  KPixmapCache& cache = const_cast<ONU*>(backGnd->onu())->automaton()->pixmapCache();
+
+  QPixmap allpm;
+  QString allpmCacheId = m_skin+m_svgid+QString::number(m_width*frames)+"x"+QString::number(m_height*nbVersions);
+  if (!cache.find(allpmCacheId, allpm))
+  {
+    // Pixmap isn't in the cache, create it and insert to cache
+    QSize size((int)(m_width*frames), (int)(m_height*nbVersions));
+    QImage image(size, QImage::Format_ARGB32_Premultiplied);
+    image.fill(0);
+    QPainter p(&image);
+    m_renderer->render(&p, m_svgid);
+    allpm = QPixmap::fromImage(image);
+
+    cache.insert(allpmCacheId, allpm);
+  }
+  
   for (unsigned int l = 0; l<nbVersions;l++)
   {
     for (unsigned int i = 0; i<frames;i++)
     {
 //       kDebug()<< "constr s : "<<m_width<<" "<<m_height<<" "<<look-1<<endl;
-      QPixmap pm =
-        allpm.copy(
-            (int)(m_width*i), (int)(m_height*l),
-            (int)(m_width), (int)(m_height));
+      QPixmap pm;
+      QString pmCacheId = m_skin+m_svgid+QString::number(m_width*frames)+"x"+QString::number(m_height*nbVersions)+"-"+QString::number(i)+":"+QString::number(l);
+      if (!cache.find(pmCacheId, pm))
+      {
+        // Pixmap isn't in the cache, create it and insert to cache
+        pm = allpm.copy((int)(m_width*i), (int)(m_height*l),
+                   (int)(m_width), (int)(m_height));
+                   
+        cache.insert(pmCacheId, pm);
+      }
+
       list.push_back(pm);
     }
   }
@@ -141,7 +160,7 @@ void AnimSprite::changeSequence(const QString &id)
 {
   kDebug() << (void*)this << id <<endl;
   changeSequence(
-          Sprites::SkinSpritesData::single().strData(id+"-id"),
+          id,
           Sprites::SkinSpritesData::single().intData(id+"-width"),
           Sprites::SkinSpritesData::single().intData(id+"-height"),
           Sprites::SkinSpritesData::single().intData(id+"-frames"),
@@ -174,15 +193,15 @@ void AnimSprite::nextFrame()
   }
   actFrame++;    // next image
 
-  if (actFrame == (frames-1))
+  if (actFrame > (frames-1))
   {
+    actFrame=0; // come back to start
     if (m_numberOfShots == 1)
     {
       setStatic();
       m_numberOfShots = std::numeric_limits<unsigned int>::max();
       kDebug() << "Emiting animationFinished" << endl;
       emit animationFinished(this);
-      return;
     }
     else if (m_numberOfShots != std::numeric_limits<unsigned int>::max())
     {
@@ -190,17 +209,13 @@ void AnimSprite::nextFrame()
       kDebug() << "numberOfShots is now " << m_numberOfShots << endl;
     }
   }
-  else if (actFrame > (frames-1))
-  {
-    actFrame=0; // come back to start
-  }
   setFrame(actFrame);
 }
 
 void AnimSprite::setFrame(unsigned int numFrame)
 {
-// kDebug() << " " << numFrame << " look=" << look <<" ; frames="
-//  <<frames<<" ; m_frames size="<<m_frames.size();
+//   kDebug() << " " << numFrame << " look=" << look <<" ; frames="
+//           <<frames<<" ; m_frames size="<<m_frames.size();
   if (numFrame < (unsigned int)m_frames.size())
   {
     setPixmap(m_frames[(look-1)*frames+numFrame]);
@@ -493,7 +508,7 @@ qreal AnimSprite::getMaxX() const
         return backGnd-> pixmap().width();
     else
     {
-        KMessageBox::error(0, i18n("Cannot find Max X  for sprite: no background !"), i18n("Error !"));
+        KMessageBox::error(0, i18n("Cannot find Max X for sprite: no background!"), i18n("Error!"));
         exit(2);
     }
 }
@@ -508,11 +523,18 @@ qreal AnimSprite::getMaxY() const
         return backGnd-> pixmap().height();
     else
     {
-        KMessageBox::error(0, i18n("Cannot find Max Y  for sprite: no background !"), i18n("Error !"));
+        KMessageBox::error(0, i18n("Cannot find Max Y for sprite: no background!"), i18n("Error!"));
         exit(2);
     }
 }
 
+void AnimSprite::setupTravel(Country* src, Country* dest, const QPointF* dpi)
+{
+  kDebug() << src->name() << dest->name() << *dpi << (dpi==0?QPointF():*dpi);
+  if (dpi ==0) AnimSprite::setupTravel(src, dest, src->centralPoint(), dest-> centralPoint());
+  else AnimSprite::setupTravel(src, dest, src->centralPoint(), *dpi);
+}
+
 /**
   * This function chooses the approach mode of a sprite towards its destination:
   * if the distance between the origin and the destination is higher than half
@@ -585,6 +607,7 @@ void AnimSprite::arrival()
   kDebug()<< "at " << destinationPoint << endl;
   if (!backGnd->bgIsArena())
   {
+    kDebug()<< "x=" << x() << "pf=" << getDestination()->pointFlag().x();
     if (x() < getDestination()-> pointFlag().x())
       setLookRight();
     else 
@@ -593,13 +616,6 @@ void AnimSprite::arrival()
   repaint();
 }
 
-void AnimSprite::setupTravel(Country* src, Country* dest, const QPointF* dpi)
-{
-  kDebug() << src->name() << dest->name() << (void*)dpi;
-  if (dpi ==0) AnimSprite::setupTravel(src, dest, src->centralPoint(), dest-> centralPoint());
-  else AnimSprite::setupTravel(src, dest, src->centralPoint(), *dpi);
-}
-
 /** Return true if the state of the sprite is the argument; false otherwise */
 bool AnimSprite::isMyState(State state) const
 {
@@ -651,7 +667,6 @@ void AnimSprite::animate()
     nextFrame();
   }
   //   kDebug() <<"finished for " << (void*)this << endl;
-  
 }
 
 void AnimSprite::setAnimated(unsigned int numberOfShots)
