@@ -20,21 +20,27 @@
 #include "kexthighscore_gui.h"
 #include "kexthighscore_gui.moc"
 
-#include <qlayout.h>
-#include <qtextstream.h>
-#include <qheader.h>
-#include <qgrid.h>
-#include <qvgroupbox.h>
+#include <QLayout>
+#include <QTextStream>
+#include <QGridLayout>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QVBoxLayout>
+#include <QGroupBox>
+#include <QHeaderView>
+#include <QtGui/QTabWidget>
 
-#include <kapplication.h>
 #include <kmessagebox.h>
 #include <kurllabel.h>
-#include <kopenwith.h>
 #include <krun.h>
 #include <kfiledialog.h>
-#include <ktempfile.h>
+#include <kvbox.h>
+#include <ktemporaryfile.h>
 #include <kio/netaccess.h>
+#include <kicon.h>
 #include <kiconloader.h>
+#include <klineedit.h>
+#include <kpushbutton.h>
 
 #include "kexthighscore_internal.h"
 #include "kexthighscore.h"
@@ -45,251 +51,286 @@ namespace KExtHighscore
 {
 
 //-----------------------------------------------------------------------------
-ShowItem::ShowItem(QListView *list, bool highlight)
-    : KListViewItem(list), _highlight(highlight)
-{}
-
-void ShowItem::paintCell(QPainter *p, const QColorGroup &cg,
-                         int column, int width, int align)
+ShowItem::ShowItem(QTreeWidget *list, bool highlight)
+    : QTreeWidgetItem(list), _highlight(highlight)
 {
-    QColorGroup cgrp(cg);
-    if (_highlight) cgrp.setColor(QColorGroup::Text, red);
-    KListViewItem::paintCell(p, cgrp, column, width, align);
+//   kDebug(11001) ;
+  if (_highlight) {
+    for (int i=0; i < columnCount();i++) {
+      setForeground(i, Qt::red);
+    }
+  }
 }
 
 //-----------------------------------------------------------------------------
 ScoresList::ScoresList(QWidget *parent)
-    : KListView(parent)
+    : QTreeWidget(parent)
 {
-    setSelectionMode(QListView::NoSelection);
-    setItemMargin(3);
+//   kDebug(11001) ;
+    setSelectionMode(QTreeWidget::NoSelection);
+//     setItemMargin(3);
     setAllColumnsShowFocus(true);
-    setSorting(-1);
-    header()->setClickEnabled(false);
-    header()->setMovingEnabled(false);
+//     setSorting(-1);
+    header()->setClickable(false);
+    header()->setMovable(false);
 }
 
 void ScoresList::addHeader(const ItemArray &items)
 {
+//   kDebug(11001) ;
     addLineItem(items, 0, 0);
 }
 
-QListViewItem *ScoresList::addLine(const ItemArray &items,
+QTreeWidgetItem *ScoresList::addLine(const ItemArray &items,
                                    uint index, bool highlight)
 {
-    QListViewItem *item = new ShowItem(this, highlight);
+//   kDebug(11001) ;
+    QTreeWidgetItem *item = new ShowItem(this, highlight);
     addLineItem(items, index, item);
     return item;
 }
 
 void ScoresList::addLineItem(const ItemArray &items,
-                             uint index, QListViewItem *line)
+                             uint index, QTreeWidgetItem *line)
 {
+//   kDebug(11001) ;
     uint k = 0;
-    for (uint i=0; i<items.size(); i++) {
-        const ItemContainer &container = *items[i];
-        if ( !container.item()->isVisible() ) continue;
-        if (line) line->setText(k, itemText(container, index));
+    for (int i=0; i<items.size(); i++) {
+        const ItemContainer& container = *items[i];
+        if ( !container.item()->isVisible() ) {
+	  continue;
+	}
+        if (line) { 
+	  line->setText(k, itemText(container, index));
+	  line->setTextAlignment(k, container.item()->alignment());
+	}
         else {
-            addColumn( container.item()->label() );
-            setColumnAlignment(k, container.item()->alignment());
+	    headerItem()->setText(k, container.item()->label() );
+            headerItem()->setTextAlignment(k, container.item()->alignment());
         }
         k++;
     }
+    update();
 }
 
 //-----------------------------------------------------------------------------
 HighscoresList::HighscoresList(QWidget *parent)
     : ScoresList(parent)
-{}
+{
+//   kDebug(11001) ;
+}
 
 QString HighscoresList::itemText(const ItemContainer &item, uint row) const
 {
+//   kDebug(11001) ;
     return item.pretty(row);
 }
 
 void HighscoresList::load(const ItemArray &items, int highlight)
 {
+//     kDebug(11001) ;
     clear();
-    QListViewItem *line = 0;
+    QTreeWidgetItem *line = 0;
     for (int j=items.nbEntries()-1; j>=0; j--) {
-        QListViewItem *item = addLine(items, j, j==highlight);
+        QTreeWidgetItem *item = addLine(items, j, j==highlight);
         if ( j==highlight ) line = item;
     }
-    if (line) ensureItemVisible(line);
+    scrollTo(indexFromItem(line));
 }
 
 //-----------------------------------------------------------------------------
 HighscoresWidget::HighscoresWidget(QWidget *parent)
-    : QWidget(parent, "show_highscores_widget"),
+    : QWidget(parent),
       _scoresUrl(0), _playersUrl(0), _statsTab(0), _histoTab(0)
 {
+//     kDebug(11001) << ": HighscoresWidget";
+
+    setObjectName("show_highscores_widget");
     const ScoreInfos &s = internal->scoreInfos();
     const PlayerInfos &p = internal->playerInfos();
 
-    QVBoxLayout *vbox = new QVBoxLayout(this, KDialogBase::spacingHint());
+    QVBoxLayout *vbox = new QVBoxLayout(this);
+    vbox->setSpacing(KDialog::spacingHint());
 
     _tw = new QTabWidget(this);
-    connect(_tw, SIGNAL(currentChanged(QWidget *)), SLOT(tabChanged()));
+    connect(_tw, SIGNAL(currentChanged(int)), SLOT(tabChanged()));
     vbox->addWidget(_tw);
 
     // scores tab
-    _scoresList = new HighscoresList(_tw);
+    _scoresList = new HighscoresList(0);
     _scoresList->addHeader(s);
     _tw->addTab(_scoresList, i18n("Best &Scores"));
 
     // players tab
-    _playersList = new HighscoresList(_tw);
+    _playersList = new HighscoresList(0);
     _playersList->addHeader(p);
     _tw->addTab(_playersList, i18n("&Players"));
 
     // statistics tab
     if ( internal->showStatistics ) {
-        _statsTab = new StatisticsTab(_tw);
+        _statsTab = new StatisticsTab(0);
         _tw->addTab(_statsTab, i18n("Statistics"));
     }
 
     // histogram tab
     if ( p.histogram().size()!=0 ) {
-        _histoTab = new HistogramTab(_tw);
+        _histoTab = new HistogramTab(0);
         _tw->addTab(_histoTab, i18n("Histogram"));
     }
 
     // url labels
     if ( internal->isWWHSAvailable() ) {
-        KURL url = internal->queryURL(ManagerPrivate::Scores);
-        _scoresUrl = new KURLLabel(url.url(),
+        KUrl url = internal->queryUrl(ManagerPrivate::Scores);
+        _scoresUrl = new KUrlLabel(url.url(),
                                    i18n("View world-wide highscores"), this);
-        connect(_scoresUrl, SIGNAL(leftClickedURL(const QString &)),
+        connect(_scoresUrl, SIGNAL(leftClickedUrl(const QString &)),
                 SLOT(showURL(const QString &)));
         vbox->addWidget(_scoresUrl);
 
-        url = internal->queryURL(ManagerPrivate::Players);
-        _playersUrl = new KURLLabel(url.url(),
+        url = internal->queryUrl(ManagerPrivate::Players);
+        _playersUrl = new KUrlLabel(url.url(),
                                     i18n("View world-wide players"), this);
-        connect(_playersUrl, SIGNAL(leftClickedURL(const QString &)),
+        connect(_playersUrl, SIGNAL(leftClickedUrl(const QString &)),
                 SLOT(showURL(const QString &)));
         vbox->addWidget(_playersUrl);
     }
+    load(-1);
 }
 
 void HighscoresWidget::changeTab(int i)
 {
-    if ( i!=_tw->currentPageIndex() )
-        _tw->setCurrentPage(i);
+//   kDebug(11001) ;
+    if ( i!=_tw->currentIndex() )
+        _tw->setCurrentIndex(i);
 }
 
-void HighscoresWidget::showURL(const QString &url) const
+void HighscoresWidget::showURL(const QString &url)
 {
-    (void)new KRun(KURL(url));
+//   kDebug(11001) ;
+    (void)new KRun(KUrl(url), this);
 }
 
 void HighscoresWidget::load(int rank)
 {
+//   kDebug(11001) << rank;
     _scoresList->load(internal->scoreInfos(), rank);
     _playersList->load(internal->playerInfos(), internal->playerInfos().id());
     if (_scoresUrl)
-        _scoresUrl->setURL(internal->queryURL(ManagerPrivate::Scores).url());
+        _scoresUrl->setUrl(internal->queryUrl(ManagerPrivate::Scores).url());
     if (_playersUrl)
-        _playersUrl->setURL(internal->queryURL(ManagerPrivate::Players).url());
+        _playersUrl->setUrl(internal->queryUrl(ManagerPrivate::Players).url());
     if (_statsTab) _statsTab->load();
     if (_histoTab) _histoTab->load();
 }
 
 //-----------------------------------------------------------------------------
 HighscoresDialog::HighscoresDialog(int rank, QWidget *parent)
-    : KDialogBase(internal->nbGameTypes()>1 ? TreeList : Plain,
-                  i18n("Highscores"), Close|User1|User2, Close,
-                  parent, "show_highscores", true, true,
-                  KGuiItem(i18n("Configure..."), "configure"),
-                  KGuiItem(i18n("Export..."))), _rank(rank), _tab(0)
+    : KPageDialog(parent), _rank(rank), _tab(0)
 {
-    _widgets.resize(internal->nbGameTypes(), 0);
+//     kDebug(11001) << ": HighscoresDialog";
 
-    if ( internal->nbGameTypes()>1 ) {
-        for (uint i=0; i<internal->nbGameTypes(); i++) {
-            QString title = internal->manager.gameTypeLabel(i, Manager::I18N);
-            QString icon = internal->manager.gameTypeLabel(i, Manager::Icon);
-            QWidget *w = addVBoxPage(title, QString::null,
-                                     BarIcon(icon, KIcon::SizeLarge));
-            if ( i==internal->gameType() ) createPage(w);
-        }
+    setCaption( i18n("Highscores") );
+    setButtons( Close|User1|User2 );
+    setDefaultButton( Close );
+    if ( internal->nbGameTypes()>1 )
+        setFaceType( KPageDialog::Tree );
+    else
+        setFaceType( KPageDialog::Plain );
+    setButtonGuiItem( User1, KGuiItem(i18n("Configure..."), "configure") );
+    setButtonGuiItem( User2, KGuiItem(i18n("Export...")) );
+    connect( this, SIGNAL(user1Clicked()), SLOT(slotUser1()) );
+    connect( this, SIGNAL(user2Clicked()), SLOT(slotUser2()) );
 
-        connect(this, SIGNAL(aboutToShowPage(QWidget *)),
-                SLOT(createPage(QWidget *)));
-        showPage(internal->gameType());
-    } else {
-        QVBoxLayout *vbox = new QVBoxLayout(plainPage());
-        createPage(plainPage());
-        vbox->addWidget(_widgets[0]);
-        setMainWidget(_widgets[0]);
+    for (uint i=0; i<internal->nbGameTypes(); i++) {
+        QString title = internal->manager.gameTypeLabel(i, Manager::I18N);
+        QString icon = internal->manager.gameTypeLabel(i, Manager::Icon);
+        HighscoresWidget *hsw = new HighscoresWidget(0);
+        KPageWidgetItem *pageItem = new KPageWidgetItem( hsw, title);
+        pageItem->setIcon( KIcon( BarIcon(icon, KIconLoader::SizeLarge) ) );
+        addPage( pageItem );
+        _pages.append(pageItem);
+        connect(hsw, SIGNAL(tabChanged(int)), SLOT(tabChanged(int)));
     }
+
+    connect(this, SIGNAL( currentPageChanged(KPageWidgetItem *, KPageWidgetItem *)),
+            SLOT(highscorePageChanged(KPageWidgetItem *, KPageWidgetItem *)));
+    setCurrentPage(_pages[internal->gameType()]);
 }
 
-void HighscoresDialog::createPage(QWidget *page)
+void HighscoresDialog::highscorePageChanged(KPageWidgetItem* page, KPageWidgetItem* pageold)
 {
+    Q_UNUSED(pageold);
+//   kDebug(11001) ;
+    int idx = _pages.indexOf( page );
+    Q_ASSERT(idx != -1);
+
     internal->hsConfig().readCurrentConfig();
-    _current = page;
-    bool several = ( internal->nbGameTypes()>1 );
-    int i = (several ? pageIndex(page) : 0);
-    if ( _widgets[i]==0 ) {
-        _widgets[i] = new HighscoresWidget(page);
-        connect(_widgets[i], SIGNAL(tabChanged(int)), SLOT(tabChanged(int)));
-    }
     uint type = internal->gameType();
-    if (several) internal->setGameType(i);
-    _widgets[i]->load(uint(i)==type ? _rank : -1);
+    bool several = ( internal->nbGameTypes()>1 );
+    if (several)
+        internal->setGameType(idx);
+    HighscoresWidget *hsw = static_cast<HighscoresWidget*>(page->widget());
+    hsw->load(uint(idx)==type ? _rank : -1);
     if (several) setGameType(type);
-    _widgets[i]->changeTab(_tab);
+    hsw->changeTab(_tab);
 }
 
 void HighscoresDialog::slotUser1()
 {
+//   kDebug(11001) ;
     if ( KExtHighscore::configure(this) )
-        createPage(_current);
+        highscorePageChanged(currentPage(), 0);//update data
 }
 
 void HighscoresDialog::slotUser2()
 {
-    KURL url = KFileDialog::getSaveURL(QString::null, QString::null, this);
+//   kDebug(11001) ;
+    KUrl url = KFileDialog::getSaveUrl(KUrl(), QString(), this);
     if ( url.isEmpty() ) return;
-    if ( KIO::NetAccess::exists(url, true, this) ) {
-        KGuiItem gi = KStdGuiItem::save();
+    if ( KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, this) ) {
+        KGuiItem gi = KStandardGuiItem::save();
         gi.setText(i18n("Overwrite"));
         int res = KMessageBox::warningContinueCancel(this,
                                  i18n("The file already exists. Overwrite?"),
                                  i18n("Export"), gi);
         if ( res==KMessageBox::Cancel ) return;
     }
-    KTempFile tmp;
-    internal->exportHighscores(*tmp.textStream());
-    tmp.close();
-    KIO::NetAccess::upload(tmp.name(), url, this);
-    tmp.unlink();
+    KTemporaryFile tmp;
+    tmp.open();
+    QTextStream stream(&tmp);
+    internal->exportHighscores(stream);
+    stream.flush();
+    KIO::NetAccess::upload(tmp.fileName(), url, this);
 }
 
 //-----------------------------------------------------------------------------
 LastMultipleScoresList::LastMultipleScoresList(
-                            const QValueVector<Score> &scores, QWidget *parent)
+                            const QVector<Score> &scores, QWidget *parent)
     : ScoresList(parent), _scores(scores)
 {
+//     kDebug(11001) << ": LastMultipleScoresList";
+
     const ScoreInfos &s = internal->scoreInfos();
     addHeader(s);
-    for (uint i=0; i<scores.size(); i++) addLine(s, i, false);
+    for (int i=0; i<scores.size(); i++) addLine(s, i, false);
 }
 
 void LastMultipleScoresList::addLineItem(const ItemArray &si,
-                                         uint index, QListViewItem *line)
+                                         uint index, QTreeWidgetItem *line)
 {
+//   kDebug(11001) ;
     uint k = 1; // skip "id"
-    for (uint i=0; i<si.size()-2; i++) {
+    for (int i=0; i<si.size()-2; i++) {
         if ( i==3 ) k = 5; // skip "date"
-        const ItemContainer *container = si[k];
+        const ItemContainer& container = *si[k];
         k++;
-        if (line) line->setText(i, itemText(*container, index));
+        if (line) {
+	  line->setText(i, itemText(container, index));
+	  line->setTextAlignment(i, container.item()->alignment());
+	}
         else {
-            addColumn(  container->item()->label() );
-            setColumnAlignment(i, container->item()->alignment());
+	    headerItem()->setText(i, container.item()->label() );
+            headerItem()->setTextAlignment(i, container.item()->alignment());
         }
     }
 }
@@ -297,9 +338,10 @@ void LastMultipleScoresList::addLineItem(const ItemArray &si,
 QString LastMultipleScoresList::itemText(const ItemContainer &item,
                                          uint row) const
 {
+//   kDebug(11001) ;
     QString name = item.name();
     if ( name=="rank" )
-        return (_scores[row].type()==Won ? i18n("Winner") : QString::null);
+        return (_scores[row].type()==Won ? i18n("Winner") : QString());
     QVariant v = _scores[row].data(name);
     if ( name=="name" ) return v.toString();
     return item.item()->pretty(row, v);
@@ -307,17 +349,19 @@ QString LastMultipleScoresList::itemText(const ItemContainer &item,
 
 //-----------------------------------------------------------------------------
 TotalMultipleScoresList::TotalMultipleScoresList(
-                            const QValueVector<Score> &scores, QWidget *parent)
+                            const QVector<Score> &scores, QWidget *parent)
     : ScoresList(parent), _scores(scores)
 {
+//     kDebug(11001) << ": TotalMultipleScoresList";
     const ScoreInfos &s = internal->scoreInfos();
     addHeader(s);
-    for (uint i=0; i<scores.size(); i++) addLine(s, i, false);
+    for (int i=0; i<scores.size(); i++) addLine(s, i, false);
 }
 
 void TotalMultipleScoresList::addLineItem(const ItemArray &si,
-                                          uint index, QListViewItem *line)
+                                          uint index, QTreeWidgetItem *line)
 {
+//   kDebug(11001) ;
     const PlayerInfos &pi = internal->playerInfos();
     uint k = 1; // skip "id"
     for (uint i=0; i<4; i++) { // skip additional fields
@@ -328,12 +372,16 @@ void TotalMultipleScoresList::addLineItem(const ItemArray &si,
             container = si[k];
             k++;
         }
-        if (line) line->setText(i, itemText(*container, index));
+
+        if (line) {
+	  line->setText(i, itemText(*container, index));
+	  line->setTextAlignment(i, container->item()->alignment());
+	}
         else {
             QString label =
                 (i==2 ? i18n("Won Games") : container->item()->label());
-            addColumn(label);
-            setColumnAlignment(i, container->item()->alignment());
+	    headerItem()->setText(i, label );
+            headerItem()->setTextAlignment(i, container->item()->alignment());
         }
     }
 }
@@ -341,6 +389,7 @@ void TotalMultipleScoresList::addLineItem(const ItemArray &si,
 QString TotalMultipleScoresList::itemText(const ItemContainer &item,
                                           uint row) const
 {
+//   kDebug(11001) ;
     QString name = item.name();
     if ( name=="rank" ) return QString::number(_scores.size()-row);
     if ( name=="nb games" )
@@ -353,17 +402,20 @@ QString TotalMultipleScoresList::itemText(const ItemContainer &item,
 
 //-----------------------------------------------------------------------------
 ConfigDialog::ConfigDialog(QWidget *parent)
-    : KDialogBase(Swallow, i18n("Configure Highscores"),
-                  Ok|Apply|Cancel, Cancel,
-                  parent, "configure_highscores", true, true),
+    : KDialog(parent),
       _saved(false), _WWHEnabled(0)
 {
+//     kDebug(11001) << ": ConfigDialog";
+    setCaption( i18n("Configure Highscores") );
+    setButtons( Ok|Apply|Cancel );
+    setDefaultButton( Cancel );
+    setModal( true );
     QWidget *page = 0;
     QTabWidget *tab = 0;
     if ( internal->isWWHSAvailable() ) {
         tab = new QTabWidget(this);
         setMainWidget(tab);
-        page = new QWidget(tab);
+        page = new QWidget;
         tab->addTab(page, i18n("Main"));
     } else {
         page = new QWidget(this);
@@ -371,7 +423,9 @@ ConfigDialog::ConfigDialog(QWidget *parent)
     }
 
     QGridLayout *pageTop =
-        new QGridLayout(page, 2, 2, spacingHint(), spacingHint());
+        new QGridLayout(page);
+    pageTop->setMargin(spacingHint());
+    pageTop->setSpacing(spacingHint());
 
     QLabel *label = new QLabel(i18n("Nickname:"), page);
     pageTop->addWidget(label, 0, 0);
@@ -397,41 +451,48 @@ ConfigDialog::ConfigDialog(QWidget *parent)
             = new QCheckBox(i18n("World-wide highscores enabled"), page);
         connect(_WWHEnabled, SIGNAL(toggled(bool)),
                 SLOT(modifiedSlot()));
-        pageTop->addMultiCellWidget(_WWHEnabled, 2, 2, 0, 1);
+        pageTop->addWidget(_WWHEnabled, 2, 0, 1, 2 );
 
         // advanced tab
-        QWidget *page = new QWidget(tab);
+        QWidget *page = new QWidget;
         tab->addTab(page, i18n("Advanced"));
-        QVBoxLayout *pageTop =
-            new QVBoxLayout(page, spacingHint(), spacingHint());
+        QVBoxLayout *pageTop = new QVBoxLayout(page);
+        pageTop->setMargin(marginHint());
+        pageTop->setSpacing(spacingHint());
 
-        QVGroupBox *group = new QVGroupBox(i18n("Registration Data"), page);
+        QGroupBox *group = new QGroupBox(page);
+        group->setTitle( i18n("Registration Data") );
         pageTop->addWidget(group);
-        QGrid *grid = new QGrid(2, group);
-        grid->setSpacing(spacingHint());
+        QGridLayout *groupLayout = new QGridLayout(group);
+        groupLayout->setSpacing(spacingHint());
 
-        label = new QLabel(i18n("Nickname:"), grid);
-        _registeredName = new KLineEdit(grid);
+        label = new QLabel(i18n("Nickname:"), group);
+        groupLayout->addWidget(label, 0, 0);
+        _registeredName = new KLineEdit(group);
         _registeredName->setReadOnly(true);
+        groupLayout->addWidget(_registeredName, 0, 1);
 
-        label = new QLabel(i18n("Key:"), grid);
-        _key = new KLineEdit(grid);
+        label = new QLabel(i18n("Key:"), group);
+        groupLayout->addWidget(label, 1, 0);
+        _key = new KLineEdit(group);
         _key->setReadOnly(true);
+        groupLayout->addWidget(_key, 1, 1);
 
-        KGuiItem gi = KStdGuiItem::clear();
+        KGuiItem gi = KStandardGuiItem::clear();
         gi.setText(i18n("Remove"));
-        _removeButton = new KPushButton(gi, grid);
+        _removeButton = new KPushButton(gi, group);
+        groupLayout->addWidget(_removeButton, 2, 0);
         connect(_removeButton, SIGNAL(clicked()), SLOT(removeSlot()));
     }
 
     load();
-    enableButtonOK( !_nickname->text().isEmpty() );
+    enableButtonOk( !_nickname->text().isEmpty() );
     enableButtonApply(false);
 }
 
 void ConfigDialog::nickNameChanged(const QString &text)
 {
-    enableButtonOK( !text.isEmpty() );
+    enableButtonOk( !text.isEmpty() );
 }
 
 
@@ -443,20 +504,20 @@ void ConfigDialog::modifiedSlot()
 void ConfigDialog::accept()
 {
     if ( save() ) {
-        KDialogBase::accept();
-        kapp->config()->sync(); // safer
+        KDialog::accept();
+        KGlobal::config()->sync(); // safer
     }
 }
 
 void ConfigDialog::removeSlot()
 {
-    KGuiItem gi = KStdGuiItem::clear();
+    KGuiItem gi = KStandardGuiItem::clear();
     gi.setText(i18n("Remove"));
     int res = KMessageBox::warningContinueCancel(this,
                                i18n("This will permanently remove your "
                                "registration key. You will not be able to use "
                                "the currently registered nickname anymore."),
-                               QString::null, gi);
+                               QString(), gi);
     if ( res==KMessageBox::Continue ) {
         internal->playerInfos().removeKey();
         _registeredName->clear();
@@ -471,7 +532,7 @@ void ConfigDialog::load()
 {
     internal->hsConfig().readCurrentConfig();
     const PlayerInfos &infos = internal->playerInfos();
-    _nickname->setText(infos.isAnonymous() ? QString::null : infos.name());
+    _nickname->setText(infos.isAnonymous() ? QString() : infos.name());
     _comment->setText(infos.comment());
     if (_WWHEnabled) {
         _WWHEnabled->setChecked(infos.isWWEnabled());
@@ -517,27 +578,36 @@ bool ConfigDialog::save()
 
 //-----------------------------------------------------------------------------
 AskNameDialog::AskNameDialog(QWidget *parent)
-    : KDialogBase(Plain, i18n("Enter Your Nickname"), Ok | Cancel, Ok,
-                  parent, "ask_name_dialog")
+    : KDialog(parent)
 {
+//     kDebug(11001) << ": AskNameDialog";
+
+    setCaption( i18n("Enter Your Nickname") );
+    setButtons( Ok | Cancel );
+    setDefaultButton( Ok );
+
     internal->hsConfig().readCurrentConfig();
+    QWidget *main = new QWidget( this );
+    setMainWidget( main );
+    QVBoxLayout *top = new QVBoxLayout( main );
+    top->setMargin( marginHint() );
+    top->setSpacing( spacingHint() );
 
-    QVBoxLayout *top =
-        new QVBoxLayout(plainPage(), marginHint(), spacingHint());
     QLabel *label =
-        new QLabel(i18n("Congratulations, you have won!"), plainPage());
+        new QLabel(i18n("Congratulations, you have won!"), main);
     top->addWidget(label);
 
-    QHBoxLayout *hbox = new QHBoxLayout(top);
-    label = new QLabel(i18n("Enter your nickname:"), plainPage());
+    QHBoxLayout *hbox = new QHBoxLayout;
+    top->addLayout(hbox);
+    label = new QLabel(i18n("Enter your nickname:"), main);
     hbox->addWidget(label);
-    _edit = new QLineEdit(plainPage());
+    _edit = new QLineEdit(main);
     _edit->setFocus();
     connect(_edit, SIGNAL(textChanged(const QString &)), SLOT(nameChanged()));
     hbox->addWidget(_edit);
 
     top->addSpacing(spacingHint());
-    _checkbox = new QCheckBox(i18n("Do not ask again."),  plainPage());
+    _checkbox = new QCheckBox(i18n("Do not ask again."),  main);
     top->addWidget(_checkbox);
 
     nameChanged();
@@ -545,7 +615,7 @@ AskNameDialog::AskNameDialog(QWidget *parent)
 
 void AskNameDialog::nameChanged()
 {
-    enableButtonOK( !name().isEmpty()
+    enableButtonOk( !name().isEmpty()
                     && !internal->playerInfos().isNameUsed(name()) );
 }
 
